@@ -175,10 +175,10 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.length = 0;
   }
 
-  ///Performs an in-place sort of the StaticVec's "inhabited" area.
+  ///Performs an *unstable* in-place sort of the StaticVec's "inhabited" area.
   pub fn sort(&mut self)
   where T: Ord {
-    self.as_mut_slice().sort();
+    self.as_mut_slice().sort_unstable();
   }
 
   ///Reverses the contents of the StaticVec's "inhabited" area in-place.
@@ -218,7 +218,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
 
   ///Copies and appends all elements in a slice to the StaticVec.
   ///Unlike the implementation of this function for Vec, no iterator is used,
-  ///just a single call to copy_non_overlapping().
+  ///just a single pointer-copy call.
   pub fn extend_from_slice(&mut self, other: &[T])
   where T: Copy {
     let mut added_length = other.len();
